@@ -16,14 +16,16 @@ QMainWindow(parent, Qt::FramelessWindowHint),
     palette.setColor(QPalette::Base, Qt::transparent);
     ui->centralWidget->setPalette(palette);
     QSettings settings;
-    if (!settings.contains("profilechangerwidget/width"))
-        settings.setValue("profilechangerwidget/width", 72);
-    if (!settings.contains("profilechangerwidget/height"))
-        settings.setValue("profilechangerwidget/height", 72);
-    if (!settings.contains("profilechangerwidget/opacity"))
-        settings.setValue("profilechangerwidget/opacity", 70);
-    if (!settings.contains("profilechangerwidget/showNextProfile"))
-        settings.setValue("profilechangerwidget/showNextProfile", true);
+    if (!settings.contains(PCW_SETTING_WIDTH))
+        settings.setValue(PCW_SETTING_WIDTH, 72);
+    if (!settings.contains(PCW_SETTING_HEIGHT))
+        settings.setValue(PCW_SETTING_HEIGHT, 72);
+    if (!settings.contains(PCW_SETTING_OPACITY))
+        settings.setValue(PCW_SETTING_OPACITY, 70);
+    if (!settings.contains(PCW_SETTING_SHOWNEXTPROFILE))
+        settings.setValue(PCW_SETTING_SHOWNEXTPROFILE, true);
+    if (!settings.contains(PCW_SETTING_LASTVERSION))
+        settings.setValue(PCW_SETTING_LASTVERSION, PCW_SETTING_LASTVERSION_DEFAULT);
 
     connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
     this->reloadSettings();
@@ -121,19 +123,19 @@ void ProfileChangerWidget::onHomeScreenChanged(bool isOnCurrentHomescreen)
 void ProfileChangerWidget::reloadSettings()
 {
     QSettings settings;
-    this->showNextProfile = settings.value("profilechangerwidget/showNextProfile").toBool();
+    this->showNextProfile = settings.value(PCW_SETTING_SHOWNEXTPROFILE).toBool();
     this->setGeometry(this->x(), this->y(),
-                      settings.value("profilechangerwidget/width").toInt(),
-                      settings.value("profilechangerwidget/height").toInt());
-    ui->switchButton->setStyleSheet("background-color: rgba(0, 0, 0, " + settings.value("profilechangerwidget/opacity").toString() + "%); \
+                      settings.value(PCW_SETTING_WIDTH).toInt(),
+                      settings.value(PCW_SETTING_HEIGHT).toInt());
+    ui->switchButton->setStyleSheet("background-color: rgba(0, 0, 0, " + settings.value(PCW_SETTING_OPACITY).toString() + "%); \
      border-style: outset; \
      border-width: 0px; \
      border-radius: 10px; \
-     border-color: rgba(0, 0, 0, " + settings.value("profilechangerwidget/opacity").toString() + "%); \
+     border-color: rgba(0, 0, 0, " + settings.value(PCW_SETTING_OPACITY).toString() + "%); \
      font: bold 14px; \
      min-width: 48px; \
-     width: " + settings.value("profilechangerwidget/width").toString() + "px; \
-     height: " + settings.value("profilechangerwidget/height").toString() + "px; \
+     width: " + settings.value(PCW_SETTING_WIDTH).toString() + "px; \
+     height: " + settings.value(PCW_SETTING_HEIGHT).toString() + "px; \
      padding: 6px;");
     this->refreshIcon();
 }
