@@ -9,10 +9,11 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
     QSettings settings;
-    ui->heightBox->setValue(settings.value("profilechangerwidget/height").toInt());
-    ui->widthBox->setValue(settings.value("profilechangerwidget/width").toInt());
-    ui->spinBoxOpacity->setValue(settings.value("profilechangerwidget/opacity").toInt());
-    ui->checkBoxNextProfile->setChecked(settings.value("profilechangerwidget/showNextProfile").toBool());
+    ui->heightBox->setValue(settings.value(PCW_SETTING_HEIGHT).toInt());
+    ui->widthBox->setValue(settings.value(PCW_SETTING_WIDTH).toInt());
+    ui->spinBoxOpacity->setValue(settings.value(PCW_SETTING_OPACITY).toInt());
+    ui->checkBoxNextProfile->setChecked(settings.value(PCW_SETTING_SHOWNEXTPROFILE).toBool());
+    connect(this, SIGNAL(rejected()), this, SLOT(close()));
 }
 
 SettingsDialog::~SettingsDialog()
@@ -28,10 +29,10 @@ void SettingsDialog::accept()
         return;
     }
 
-    settings.setValue("profilechangerwidget/width", ui->widthBox->value());
-    settings.setValue("profilechangerwidget/height", ui->heightBox->value());
-    settings.setValue("profilechangerwidget/opacity", ui->spinBoxOpacity->value());
-    settings.setValue("profilechangerwidget/showNextProfile", ui->checkBoxNextProfile->isChecked());
+    settings.setValue(PCW_SETTING_WIDTH, ui->widthBox->value());
+    settings.setValue(PCW_SETTING_HEIGHT, ui->heightBox->value());
+    settings.setValue(PCW_SETTING_OPACITY, ui->spinBoxOpacity->value());
+    settings.setValue(PCW_SETTING_SHOWNEXTPROFILE, ui->checkBoxNextProfile->isChecked());
     emit settingsChanged();
     this->close();
 }
@@ -64,6 +65,28 @@ void SettingsDialog::showAbout()
     this->close();
 }
 
+void SettingsDialog::checkVersion() {
+    QSettings settings;
+    QString oldVersion = settings.value(PCW_SETTING_LASTVERSION).toString();
+    QString curVersion = QApplication::applicationVersion();
+    if(oldVersion != curVersion) {
+        settings.setValue(PCW_SETTING_LASTVERSION, curVersion);
+        QString tmpInfo;
+        if(oldVersion == PCW_SETTING_LASTVERSION_DEFAULT) {
+            //Show info for user that have installed the app for the first time.
+            tmpInfo.append(tr("Thank you for installing profile changer widget."));
+        } else {
+            //Show update info
+            tmpInfo.append(tr("Thank you for updating profile changer widget."));
+        }
+        tmpInfo.append("\n");
+        tmpInfo.append(tr("Feel free to support my work by testing the application in order to get it to Extras -repository."));
+        tmpInfo.append("\n");
+        tmpInfo.append(tr("Therefore you can use the \"Feedback\" button."));
+        this->showQuestion(tmpInfo);
+    }
+}
+
 void SettingsDialog::on_buttonAbout_clicked()
 {
     this->showAbout();
@@ -118,3 +141,18 @@ void SettingsDialog::showInformation(QString info)
     msg = QDBusConnection::sessionBus().call(msg);
 
 }
+
+void SettingsDialog::showQuestion(QString info)
+{
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        "org.freedesktop.Notifications", // --dest
+        "/org/freedesktop/Notifications", // destination object path
+        "org.freedesktop.Notifications", // message name (w/o method)
+        "SystemNoteDialog" // method
+    );
+    msg << info;
+    msg << 0;
+    msg << "Ok";
+    msg = QDBusConnection::sessionBus().call(msg);
+
+}
