@@ -6,6 +6,14 @@
 #include <QPushButton>
 #include <QDBusInterface>
 
+#define PCW_SETTING_HEIGHT "profilechangerwidget/height"
+#define PCW_SETTING_WIDTH "profilechangerwidget/width"
+#define PCW_SETTING_OPACITY "profilechangerwidget/opacity"
+#define PCW_SETTING_SHOWNEXTPROFILE "profilechangerwidget/showNextProfile"
+#define PCW_SETTING_LASTVERSION "profilechangerwidget/lastVersion"
+#define PCW_SETTING_LASTVERSION_DEFAULT "0.0"
+#define PCW_APP_VERSION "0.9.1"
+
 namespace Ui {
     class SettingsDialog;
 }
@@ -20,11 +28,13 @@ signals:
 public:
     explicit SettingsDialog(QWidget *parent = 0);
     ~SettingsDialog();
+    void checkVersion();
 
 private:
     Ui::SettingsDialog *ui;
     void openBrowser(QString url);
     void showInformation(QString info);
+    void showQuestion(QString info);
 
 private slots:
     void accept();
